@@ -1,4 +1,4 @@
-# ABSTRACT: Data Type Object Orientation for Perl 5
+# ABSTRACT: Object Orientation for Perl 5
 package Data::Object;
 
 use 5.010;
@@ -10,7 +10,7 @@ use Carp;
 use Exporter qw(import);
 use Scalar::Util qw(blessed looks_like_number reftype);
 
-our @EXPORT_OK = qw(
+my @CORE = grep !/^(data|type)_/, our @EXPORT_OK = qw(
     alias
     codify
     const
@@ -47,12 +47,12 @@ our @EXPORT_OK = qw(
 
 our %EXPORT_TAGS = (
     all  => [@EXPORT_OK],
-    core => [qw(alias deduce deduce_deep detract detract_deep load throw)],
+    core => [@CORE],
     data => [grep m/data_/, @EXPORT_OK],
     type => [grep m/type_/, @EXPORT_OK],
 );
 
-our $VERSION = '0.37'; # VERSION
+our $VERSION = '0.38'; # VERSION
 
 sub new {
     shift and goto &deduce_deep;
@@ -79,8 +79,7 @@ sub const ($$) {
 
     my $class = caller(0);
        $class = caller(1) if __PACKAGE__ eq $class;
-
-    my $fqsn = $name =~ /(::|')/ ? $name : "${class}::${name}";
+    my $fqsn  = $name =~ /(::|')/ ? $name : "${class}::${name}";
 
     no strict 'refs';
     no warnings 'redefine';
@@ -367,11 +366,11 @@ __END__
 
 =head1 NAME
 
-Data::Object - Data Type Object Orientation for Perl 5
+Data::Object - Object Orientation for Perl 5
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -414,8 +413,9 @@ The all export tag will export all exportable functions.
 
     use Data::Object qw(:core);
 
-The core export tag will export the exportable functions C<alias>, C<deduce>,
-C<deduce_deep>, C<detract>, C<detract_deep>, C<load>, and C<throw> exclusively.
+The core export tag will export the exportable functions C<alias>, C<const>,
+C<deduce>, C<deduce_deep>, C<detract>, C<detract_deep>, C<load>, and C<throw>
+exclusively.
 
 =head2 data
 
