@@ -1,10 +1,10 @@
-# ABSTRACT: A Generic Role Framework for Perl 5
+# ABSTRACT: Role Declaration for Perl 5
 package Data::Object::Role;
 
 use 5.010;
 use parent 'Moo::Role';
 
-our $VERSION = '0.37'; # VERSION
+our $VERSION = '0.38'; # VERSION
 
 1;
 
@@ -16,11 +16,11 @@ __END__
 
 =head1 NAME
 
-Data::Object::Role - A Generic Role Framework for Perl 5
+Data::Object::Role - Role Declaration for Perl 5
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -31,8 +31,7 @@ version 0.37
     extends 'Entity';
     with    'Identity';
 
-    has firstname => ( is => 'ro' );
-    has lastname  => ( is => 'ro' );
+    has id => ( is => 'ro' );
 
     1;
 
